
import React, { useState, useMemo } from 'react';
import { useNavigate } from 'react-router-dom';
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from '@/components/ui/card';
import { Badge } from '@/components/ui/badge';
import { Button } from '@/components/ui/button';
import { ChevronRight } from 'lucide-react';
import { allGuides } from '@/data/guides';
import GuideCategories from '@/components/guides/GuideCategories';

type CategoryType = 'all' | 'Beginner' | 'Gaming' | 'Professional' | 'Hardware' | 'Advanced' | 'Security' | 'Maintenance' | 'Performance';

const Guides = () => {
  const navigate = useNavigate();
  const [activeCategory, setActiveCategory] = useState<CategoryType>('all');
  
  // Filter guides by category
  const filteredGuides = useMemo(() => {
    if (activeCategory === 'all') return allGuides;
    return allGuides.filter(guide => guide.category === activeCategory);
  }, [activeCategory]);
  
  // Count guides by category
  const categoryCounts = useMemo(() => {
    const counts: Record<string, number> = { all: allGuides.length };
    allGuides.forEach(guide => {
      counts[guide.category] = (counts[guide.category] || 0) + 1;
    });
    return counts;
  }, []);
  
  const handleGuideClick = (guideId: string) => {
    console.log(`Navigating to guide: ${guideId}`);
    navigate(`/guide/${guideId}`);
  };

  return (
    <div className="container mx-auto py-12 px-4">
      <div className="max-w-5xl mx-auto">
        <div className="text-center mb-12">
          <h1 className="text-3xl font-bold mb-3">PC Building Guides</h1>
          <p className="text-muted-foreground max-w-2xl mx-auto">
            Learn everything you need to know about building and optimizing your PC with our comprehensive guides.
          </p>
        </div>
        
        <GuideCategories 
          activeCategory={activeCategory} 
          onCategoryChange={setActiveCategory} 
          categoryCounts={categoryCounts}
        />
        
        {filteredGuides.length === 0 ? (
          <div className="text-center p-12 border rounded-lg bg-muted/30">
            <p className="text-lg font-medium mb-2">No guides found</p>
            <p className="text-muted-foreground">No guides match the selected category.</p>
          </div>
        ) : (
          <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
            {filteredGuides.map((guide) => (
              <Card 
                key={guide.id} 
                className="overflow-hidden shadow-lg hover:shadow-xl transition-shadow cursor-pointer group"
                onClick={() => handleGuideClick(guide.id)}
              >
                <CardHeader className="pb-3">
                  <div className="flex justify-between items-center mb-2">
                    <Badge variant="outline" className="bg-primary/10 text-primary border-primary/20">
                      {guide.category}
                    </Badge>
                    <span className="text-sm text-muted-foreground">
                      {Math.ceil(guide.content.length / 2000)} min read
                    </span>
                  </div>
                  <CardTitle className="flex items-center gap-2">
                    {guide.icon}
                    {guide.title}
                  </CardTitle>
                  <CardDescription>
                    {guide.description}
                  </CardDescription>
                </CardHeader>
                <CardFooter>
                  <Button 
                    variant="ghost" 
                    className="w-full justify-between group"
                    onClick={(e) => {
                      e.stopPropagation(); // Prevent card click event
                      handleGuideClick(guide.id);
                    }}
                  >
                    Read Guide
                    <ChevronRight className="h-4 w-4 group-hover:translate-x-1 transition-transform" />
                  </Button>
                </CardFooter>
              </Card>
            ))}
          </div>
        )}
      </div>
    </div>
  );
};

export default Guides;
